@@ -16,15 +16,14 @@ from .columns import (
 )
 from .config import RequestConfig
 from .paginators import LazyPaginator
-from .tables import Table, TableBase, table_factory
+from .tables import Table, table_factory
 from .utils import A
 from .views import MultiTableMixin, SingleTableMixin, SingleTableView
 
-__version__ = "2.2.0"
+__version__ = "2.3.0"
 
 __all__ = (
     "Table",
-    "TableBase",
     "table_factory",
     "BooleanColumn",
     "Column",
